@@ -5,7 +5,7 @@
 %%
 %% %CopyrightBegin%
 %%
-%% Copyright Ericsson AB 1996-2015. All Rights Reserved.
+%% Copyright Ericsson AB 1996-2018. All Rights Reserved.
 %%
 %% Licensed under the Apache License, Version 2.0 (the "License");
 %% you may not use this file except in compliance with the License.
@@ -60,8 +60,7 @@ return_error(Line, Message) ->
 yeccpars0(Tokens, Tzr, State, States, Vstack) ->
     try yeccpars1(Tokens, Tzr, State, States, Vstack)
     catch 
-        error: Error ->
-            Stacktrace = erlang:get_stacktrace(),
+        error: Error: Stacktrace ->
             try yecc_error_type(Error, Stacktrace) of
                 Desc ->
                     erlang:raise(error, {yecc_bug, ?CODE_VERSION, Desc},
@@ -155,27 +154,26 @@ yecctoken_location(Token) ->
     end.
 
 -compile({nowarn_unused_function, yecctoken2string/1}).
-yecctoken2string({atom, _, A}) -> io_lib:write(A);
+yecctoken2string({atom, _, A}) -> io_lib:write_atom(A);
 yecctoken2string({integer,_,N}) -> io_lib:write(N);
 yecctoken2string({float,_,F}) -> io_lib:write(F);
 yecctoken2string({char,_,C}) -> io_lib:write_char(C);
 yecctoken2string({var,_,V}) -> io_lib:format("~s", [V]);
 yecctoken2string({string,_,S}) -> io_lib:write_string(S);
 yecctoken2string({reserved_symbol, _, A}) -> io_lib:write(A);
-yecctoken2string({_Cat, _, Val}) -> io_lib:format("~p",[Val]);
+yecctoken2string({_Cat, _, Val}) -> io_lib:format("~tp", [Val]);
 yecctoken2string({dot, _}) -> "'.'";
-yecctoken2string({'$end', _}) ->
-    [];
+yecctoken2string({'$end', _}) -> [];
 yecctoken2string({Other, _}) when is_atom(Other) ->
-    io_lib:write(Other);
+    io_lib:write_atom(Other);
 yecctoken2string(Other) ->
-    io_lib:write(Other).
+    io_lib:format("~tp", [Other]).
 
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
 
 
--file("xmerl_b64Bin.erl", 178).
+-file("xmerl_b64Bin.erl", 176).
 
 -dialyzer({nowarn_function, yeccpars2/7}).
 yeccpars2(0=S, Cat, Ss, Stack, T, Ts, Tzr) ->
@@ -303,14 +301,14 @@ yeccpars2_12(_, _, _, _, T, _, _) ->
  yeccerror(T).
 
 yeccpars2_13(_S, '=', Ss, Stack, T, Ts, Tzr) ->
- NewStack = 'yeccpars2_13_='(Stack),
+ NewStack = 'yeccpars2_13_\'=\''(Stack),
  yeccgoto_b16(hd(Ss), '=', Ss, NewStack, T, Ts, Tzr);
 yeccpars2_13(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  NewStack = yeccpars2_13_(Stack),
  yeccgoto_b64(hd(Ss), Cat, Ss, NewStack, T, Ts, Tzr).
 
 yeccpars2_14(_S, '=', Ss, Stack, T, Ts, Tzr) ->
- NewStack = 'yeccpars2_14_='(Stack),
+ NewStack = 'yeccpars2_14_\'=\''(Stack),
  yeccgoto_b16(hd(Ss), '=', Ss, NewStack, T, Ts, Tzr);
 yeccpars2_14(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  NewStack = yeccpars2_14_(Stack),
@@ -418,9 +416,9 @@ yeccpars2_10_(__Stack0) ->
    '$undefined'
   end | __Stack].
 
--compile({inline,'yeccpars2_13_='/1}).
+-compile({inline,'yeccpars2_13_\'=\''/1}).
 -file("xmerl_b64Bin.yrl", 0).
-'yeccpars2_13_='(__Stack0) ->
+'yeccpars2_13_\'=\''(__Stack0) ->
  [__1 | __Stack] = __Stack0,
  [begin
    '$undefined'
@@ -434,9 +432,9 @@ yeccpars2_13_(__Stack0) ->
    '$undefined'
   end | __Stack].
 
--compile({inline,'yeccpars2_14_='/1}).
+-compile({inline,'yeccpars2_14_\'=\''/1}).
 -file("xmerl_b64Bin.yrl", 0).
-'yeccpars2_14_='(__Stack0) ->
+'yeccpars2_14_\'=\''(__Stack0) ->
  [__1 | __Stack] = __Stack0,
  [begin
    '$undefined'
